@@ -32,7 +32,12 @@ import numpy as np
 from functools import partial
 from operator import getitem
 
-from ..topology_graph import TopologyGraph, NullOptimizer, EdgeGroup
+from ..topology_graph import (
+    TopologyGraph,
+    NullOptimizer,
+    EdgeGroup,
+    PeriodicConstructionResult,
+)
 from .vertices import _UnaligningVertex
 from .edge import _CofEdge
 from ...reactions import GenericReactionFactory
@@ -95,10 +100,12 @@ class Cof(TopologyGraph):
 
     For :class:`.Cof` topologies, it is recommend to use the
     :class:`.Collapser` optimizer if using the nonperiodic form.
-    However, no optimizer is valid for periodic systems currently.
+    For periodic systems, the :class:`.PeriodicCollapser` is
+    recommended.
 
     .. code-block:: python
 
+        # Nonperiodic.
         cof = stk.ConstructedMolecule(
             topology_graph=stk.cof.Honeycomb(
                 building_blocks=(bb1, bb2),
@@ -109,12 +116,21 @@ class Cof(TopologyGraph):
             ),
         )
 
-    *Accessing the Periodic Unit Cell*
+        # Periodic.
+        cof = stk.ConstructedMolecule(
+            topology_graph=stk.cof.PeriodicHoneycomb(
+                building_blocks=(bb1, bb2),
+                lattice_size=(3, 3, 1),
+                optimizer=stk.PeriodicCollapser(),
+            ),
+        )
 
-    The same :class:`.Cof` instance can be built as a periodic
-    structure, which has a unit cell (assuming as P1 space group) that
-    can be accessed at any time from the :class:`.TopologyGraph`
-    instance.
+    *Accessing the Periodic Information*
+
+    When building periodic :class:`.Cof` instances, the periodic
+    information, such as the unit cell, can be accessed if you use the
+    :class:`.PeriodicConstructionResult` returned by calling
+    :meth:`.Cof.construct`
 
     .. code-block:: python
 
@@ -122,8 +138,11 @@ class Cof(TopologyGraph):
             building_blocks=(bb1, bb2),
             lattice_size=(3, 3, 1),
         )
-        cof = stk.ConstructedMolecule(topology_graph)
-        periodic_info = topology.get_periodic_info()
+        construction_result = topology_graph.construct()
+        cof = stk.ConstructedMolecule.init_from_construction_result(
+            construction_result=construction_result,
+        )
+        periodic_info = construction_result.get_periodic_info()
         cell_matrix = periodic_info.get_cell_matrix()
         # Can access all unit-cell parameters.
         a = periodic_info.get_a()
@@ -132,6 +151,13 @@ class Cof(TopologyGraph):
         alpha = periodic_info.get_alpha()
         beta = periodic_info.get_beta()
         gamma = periodic_info.get_gamma()
+        # Write to .pdb file.
+        writer = stk.PdbWriter()
+        writer.write(
+            molecule=cof,
+            path='cof.pdb',
+            periodic_info=periodic_info,
+        )
 
     *Structural Isomer Construction*
 
@@ -663,6 +689,22 @@ class Cof(TopologyGraph):
     def _get_lattice_constants(self):
         return self._lattice_constants
 
+    def construct(self):
+        """
+        Construct a :class:`.ConstructedMolecule`.
+
+        Returns
+        -------
+        :class:`.PeriodicConstructionResult`
+            The data describing the :class:`.ConstructedMolecule`.
+
+        """
+
+        return super().construct()
+
+    def _get_construction_result(self, state):
+        return PeriodicConstructionResult(state, self._lattice_size)
+
     def _get_scale(self, building_block_vertices):
         return 5*max(
             bb.get_maximum_diameter()
