@@ -5,6 +5,7 @@ Periodic Square
 """
 
 import numpy as np
+import warnings
 from ...reactions import GenericReactionFactory
 from .cof import Cof
 from .vertices import _LinearCofVertex, _NonLinearCofVertex
@@ -28,8 +29,8 @@ class PeriodicSquare(Cof):
         | 4-functional groups: 0
         | 2-functional groups: 1 to 2
 
-    Note that :class:`.Optimizer` does not optimize the
-    :class:`.PeriodicInfo`.
+    Note that optimizers may not optimize the :class:`.PeriodicInfo`.
+    The documentation of the optimizer will state if it does.
 
     See :class:`.Cof` for more details and examples.
 
@@ -133,6 +134,15 @@ class PeriodicSquare(Cof):
 
         """
 
+        warnings.warn(
+            'You called get_periodic_info() on a topology graph '
+            'instance. This method will be removed in any version '
+            'of stk released on, or after, 21/10/21. Please call '
+            'the construct() method instead. This will return a '
+            'PeriodicConstructionResult which provides the new '
+            'get_periodic_info() method.'
+        )
+
         lattice_constants = self._get_lattice_constants()
 
         return PeriodicInfo(
