@@ -5,13 +5,15 @@ Host Guest Complex
 """
 
 from .vertices import _HostVertex, _GuestVertex
-from ..topology_graph import TopologyGraph
+from ..topology_graph import TopologyGraph, NullOptimizer
 
 
 class Complex(TopologyGraph):
     """
     Represents a host-guest complex topology graph.
 
+    Host and guest building blocks do not require functional groups.
+
     Examples
     --------
     *Construction*
@@ -41,6 +43,13 @@ class Complex(TopologyGraph):
             ),
         )
 
+    *Suggested Optimization*
+
+    For :class:`.Complex` topologies, there is no need to use an
+    optimizer, so stick with :class:`.NullOptimizer`. However, it is
+    recommended that all building blocks be optimized prior to
+    construction.
+
     *Changing the Position of the Guest*
 
     You can change the position and orientation of the guest, as well
@@ -73,6 +82,7 @@ class Complex(TopologyGraph):
         guest_target=None,
         displacement=(0, 0, 0),
         num_processes=1,
+        optimizer=NullOptimizer(),
     ):
         """
         Initialize an instance of :class:`.Complex`.
@@ -100,6 +110,10 @@ class Complex(TopologyGraph):
             The number of parallel processes to create during
             :meth:`construct`.
 
+        optimizer : :class:`.Optimizer`, optional
+            Used to optimize the structure of the constructed
+            molecule.
+
         Raises
         ------
         :class:`TypeError`
@@ -140,6 +154,7 @@ class Complex(TopologyGraph):
             reaction_factory=None,
             construction_stages=(),
             num_processes=num_processes,
+            optimizer=optimizer,
             edge_groups=(),
         )
 
