@@ -7,7 +7,7 @@ Linear
 import numpy as np
 
 from .vertices import _HeadVertex, _TailVertex, _LinearVertex
-from ...topology_graph import TopologyGraph, Edge
+from ...topology_graph import TopologyGraph, Edge, NullOptimizer
 from ....reactions import GenericReactionFactory
 
 
@@ -15,6 +15,10 @@ class Linear(TopologyGraph):
     """
     Represents a linear polymer topology graph.
 
+    Building blocks with two functional groups are required, unless the
+    building block's position is specified to only be at the capping
+    positions.
+
     Examples
     --------
     *Construction*
@@ -35,6 +39,24 @@ class Linear(TopologyGraph):
             ),
         )
 
+    *Suggested Optimization*
+
+    For :class:`.Linear` topologies, it is recommend to use the
+    :class:`.Collapser` optimizer.
+
+    .. code-block:: python
+
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(bb1, bb2),
+                repeating_unit='AB',
+                num_repeating_units=12,
+                # Setting scale_steps to False tends to lead to a
+                # better structure.
+                optimizer=stk.Collapser(scale_steps=False),
+            ),
+        )
+
     *Construction with Capping Units*
 
     Building blocks with a single functional group can
@@ -164,6 +186,7 @@ class Linear(TopologyGraph):
         random_seed=None,
         reaction_factory=GenericReactionFactory(),
         num_processes=1,
+        optimizer=NullOptimizer(),
     ):
         """
         Initialize a :class:`Linear` instance.
@@ -214,6 +237,10 @@ class Linear(TopologyGraph):
             The number of parallel processes to create during
             :meth:`construct`.
 
+        optimizer : :class:`.Optimizer`, optional
+            Used to optimize the structure of the constructed
+            molecule.
+
         Raises
         ------
         :class:`ValueError`
@@ -283,6 +310,7 @@ class Linear(TopologyGraph):
             edges=tuple(edges),
             reaction_factory=reaction_factory,
             construction_stages=(),
+            optimizer=optimizer,
             num_processes=num_processes,
         )
 
