@@ -7,6 +7,11 @@ Optimizer
 
     Collapser <\
 stk.molecular.topology_graphs.topology_graph.optimizers.collapser\
+>
+
+    Periodic Collapser <\
+stk.molecular.topology_graphs.topology_graph.optimizers.\
+periodic_collapser\
 >
 
     MCHammer <\
